@@ -196,54 +196,14 @@ doesn't make it through, because the root logger sports a higher setting
 
 =head2 How can I install Log::Log4perl on Microsoft Windows?
 
-Log::Log4perl is fully supported on the Win32 platform. It has been tested 
-with Activestate perl 5.6.1 under Windows 98 and rumor has it that it
-also runs smoothly on all other major flavors (Windows NT, 2000, XP, etc.).
+You can install Log::Log4perl using the CPAN client.
 
-It also runs nicely with ActiveState 5.8.0, and, believe me, 
-we had to jump through some major hoops for that.
+Alternatively you can install it using 
 
-Typically, Win32 systems don't have the C<make> utility installed,
-so the standard C<perl Makefile.PL; make install> on the downloadable
-distribution won't work. But don't despair, there's a very easy solution!
+    ppm install Log-Log4perl
 
-The C<Log::Log4perl> homepage provides a so-called PPD file for ActiveState's
-C<ppm> installer, which comes with ActiveState perl by default.
+if you're using ActiveState perl.
 
-=over 4
-
-=item Install on ActiveState 5.6.*
-
-The DOS command line
-
-    ppm install "http://log4perl.sourceforge.net/ppm/Log-Log4perl.ppd"
-
-will contact the Log4perl homepage, download the latest
-C<Log::Log4perl>
-distribution and install it. If your ActiveState installation
-lacks any of the modules C<Log::Log4perl> depends upon, C<ppm> will 
-automatically contact ActivateState and download them from their CPAN-like
-repository.
-
-=item Install on ActiveState 5.8.*
-
-ActiveState's "Programmer's Package Manager" can be called from
-Window's Start Menu:
-Start-E<gt>Programs->E<gt>ActiveState ActivePerl 5.8E<gt>Perl Package Manager
-will invoke ppm. Since Log::Log4perl hasn't made it yet into the standard
-ActiveState repository (and you probably don't want their outdated packages
-anyway), just tell ppm the first time you call it to add the Log4perl 
-repository
-
-    ppm> repository add http://log4perl.sourceforge.net/ppm
-
-Then, just tell it to install Log::Log4perl and it will resolve all
-dependencies automatically and fetch them from log4perl.sourceforge.net
-if it can't find them in the main archives:
-
-    ppm> install Log-Log4perl
-
-=back
 
 That's it! Afterwards, just create a Perl script like
 
@@ -258,7 +218,7 @@ and run it. It should print something like
     2002/11/06 01:22:05 Watch me!
 
 If you find that something doesn't work, please let us know at
-log4perl-devel@lists.sourceforge.net -- we'll apprechiate it. Have fun!
+log4perl-devel@lists.sourceforge.net -- we'll appreciate it. Have fun!
 
 =head2 How can I include global (thread-specific) data in my log messages?
 
@@ -1770,11 +1730,11 @@ module along with regular Log::Log4perl initialization:
         });
 
     tie *STDERR, "Trapper";
-    
+
 Make sure not to use STDERR as Log::Log4perl's file appender
 here (which would be the default in C<:easy> mode), because it would 
 end up in an endless recursion.
-    
+
 Now, calling
 
     IgnorantModule::some_method();
@@ -2600,7 +2560,7 @@ Log::Log4perl
 
 =head1 LICENSE
 
-Copyright 2002-2012 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+Copyright 2002-2013 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
 and Kevin Goess E<lt>cpan@goess.orgE<gt>.
 
 This library is free software; you can redistribute it and/or modify
@@ -2625,7 +2585,8 @@ Contributors (in alphabetical order):
 Ateeq Altaf, Cory Bennett, Jens Berthold, Jeremy Bopp, Hutton
 Davidson, Chris R. Donnelly, Matisse Enzer, Hugh Esco, Anthony
 Foiani, James FitzGibbon, Carl Franks, Dennis Gregorovic, Andy
-Grundman, Paul Harrington, David Hull, Robert Jacobson, Jason Kohles, 
-Jeff Macdonald, Markus Peter, Brett Rann, Peter Rabbitson, Erik
-Selberg, Aaron Straup Cope, Lars Thegler, David Viner, Mac Yang.
+Grundman, Paul Harrington, Alexander Hartmaier  David Hull, 
+Robert Jacobson, Jason Kohles, Jeff Macdonald, Markus Peter, 
+Brett Rann, Peter Rabbitson, Erik Selberg, Aaron Straup Cope, 
+Lars Thegler, David Viner, Mac Yang.
 
